#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-JzLVaznTqvpJZfadUiFrU0
key:                  interpolate-0.2.1-JzLVaznTqvpJZfadUiFrU0
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  9b122728d4d32bc39208575a9c2203f4
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-JzLVaznTqvpJZfadUiFrU0
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-7BPRFmc5zny8wHSLYyivmP
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

